<a id="mypy-boto3-panorama"></a>

# mypy-boto3-panorama

[![PyPI - mypy-boto3-panorama](https://img.shields.io/pypi/v/mypy-boto3-panorama.svg?color=blue)](https://pypi.org/project/mypy-boto3-panorama)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-panorama.svg?color=blue)](https://pypi.org/project/mypy-boto3-panorama)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dm/mypy-boto3-panorama?color=blue)](https://pypistats.org/packages/mypy-boto3-panorama)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.Panorama 1.19.12](https://boto3.amazonaws.com/v1/documentation/api/1.19.12/reference/services/panorama.html#Panorama)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 6.1.2](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-panorama docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_panorama/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-panorama](#mypy-boto3-panorama)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `Panorama` service.

```bash
python -m pip install boto3-stubs[panorama]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[panorama]` in your environment:
  `python -m pip install 'boto3-stubs[panorama]'`

Both type checking and auto-complete should work for `Panorama` service. No
explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[panorama]` in your environment:
  `python -m pip install 'boto3-stubs[panorama]'`

Both type checking and auto-complete should work for `Panorama` service. No
explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[panorama]` in your environment:
  `python -m pip install 'boto3-stubs[panorama]'`
- Run `mypy` as usual

Type checking should work for `Panorama` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[panorama]` in your environment:
  `python -m pip install 'boto3-stubs[panorama]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Panorama` service. No explicit type annotations
required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`PanoramaClient` provides annotations for `boto3.client("panorama")`.

```python
import boto3

from mypy_boto3_panorama import PanoramaClient

client: PanoramaClient = boto3.client("panorama")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: PanoramaClient = session.client("panorama")
```

<a id="literals"></a>

### Literals

`mypy_boto3_panorama.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_panorama.literals import (
    ApplicationInstanceHealthStatusType,
    ApplicationInstanceStatusType,
    ConnectionTypeType,
    DeviceConnectionStatusType,
    DeviceStatusType,
    DeviceTypeType,
    JobResourceTypeType,
    JobTypeType,
    NetworkConnectionStatusType,
    NodeCategoryType,
    NodeFromTemplateJobStatusType,
    NodeInstanceStatusType,
    PackageImportJobStatusType,
    PackageImportJobTypeType,
    PackageVersionStatusType,
    PortTypeType,
    StatusFilterType,
    TemplateTypeType,
    UpdateProgressType,
    ServiceName,
)

def check_value(value: ApplicationInstanceHealthStatusType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_panorama.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_panorama.type_defs import (
    ApplicationInstanceTypeDef,
    CreateApplicationInstanceRequestRequestTypeDef,
    CreateApplicationInstanceResponseTypeDef,
    CreateJobForDevicesRequestRequestTypeDef,
    CreateJobForDevicesResponseTypeDef,
    CreateNodeFromTemplateJobRequestRequestTypeDef,
    CreateNodeFromTemplateJobResponseTypeDef,
    CreatePackageImportJobRequestRequestTypeDef,
    CreatePackageImportJobResponseTypeDef,
    CreatePackageRequestRequestTypeDef,
    CreatePackageResponseTypeDef,
    DeleteDeviceRequestRequestTypeDef,
    DeleteDeviceResponseTypeDef,
    DeletePackageRequestRequestTypeDef,
    DeregisterPackageVersionRequestRequestTypeDef,
    DescribeApplicationInstanceDetailsRequestRequestTypeDef,
    DescribeApplicationInstanceDetailsResponseTypeDef,
    DescribeApplicationInstanceRequestRequestTypeDef,
    DescribeApplicationInstanceResponseTypeDef,
    DescribeDeviceJobRequestRequestTypeDef,
    DescribeDeviceJobResponseTypeDef,
    DescribeDeviceRequestRequestTypeDef,
    DescribeDeviceResponseTypeDef,
    DescribeNodeFromTemplateJobRequestRequestTypeDef,
    DescribeNodeFromTemplateJobResponseTypeDef,
    DescribeNodeRequestRequestTypeDef,
    DescribeNodeResponseTypeDef,
    DescribePackageImportJobRequestRequestTypeDef,
    DescribePackageImportJobResponseTypeDef,
    DescribePackageRequestRequestTypeDef,
    DescribePackageResponseTypeDef,
    DescribePackageVersionRequestRequestTypeDef,
    DescribePackageVersionResponseTypeDef,
    DeviceJobConfigTypeDef,
    DeviceJobTypeDef,
    DeviceTypeDef,
    EthernetPayloadTypeDef,
    EthernetStatusTypeDef,
    JobResourceTagsTypeDef,
    JobTypeDef,
    ListApplicationInstanceDependenciesRequestRequestTypeDef,
    ListApplicationInstanceDependenciesResponseTypeDef,
    ListApplicationInstanceNodeInstancesRequestRequestTypeDef,
    ListApplicationInstanceNodeInstancesResponseTypeDef,
    ListApplicationInstancesRequestRequestTypeDef,
    ListApplicationInstancesResponseTypeDef,
    ListDevicesJobsRequestRequestTypeDef,
    ListDevicesJobsResponseTypeDef,
    ListDevicesRequestRequestTypeDef,
    ListDevicesResponseTypeDef,
    ListNodeFromTemplateJobsRequestRequestTypeDef,
    ListNodeFromTemplateJobsResponseTypeDef,
    ListNodesRequestRequestTypeDef,
    ListNodesResponseTypeDef,
    ListPackageImportJobsRequestRequestTypeDef,
    ListPackageImportJobsResponseTypeDef,
    ListPackagesRequestRequestTypeDef,
    ListPackagesResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ManifestOverridesPayloadTypeDef,
    ManifestPayloadTypeDef,
    NetworkPayloadTypeDef,
    NetworkStatusTypeDef,
    NodeFromTemplateJobTypeDef,
    NodeInputPortTypeDef,
    NodeInstanceTypeDef,
    NodeInterfaceTypeDef,
    NodeOutputPortTypeDef,
    NodeTypeDef,
    OTAJobConfigTypeDef,
    OutPutS3LocationTypeDef,
    PackageImportJobInputConfigTypeDef,
    PackageImportJobOutputConfigTypeDef,
    PackageImportJobOutputTypeDef,
    PackageImportJobTypeDef,
    PackageListItemTypeDef,
    PackageObjectTypeDef,
    PackageVersionInputConfigTypeDef,
    PackageVersionOutputConfigTypeDef,
    ProvisionDeviceRequestRequestTypeDef,
    ProvisionDeviceResponseTypeDef,
    RegisterPackageVersionRequestRequestTypeDef,
    RemoveApplicationInstanceRequestRequestTypeDef,
    ResponseMetadataTypeDef,
    S3LocationTypeDef,
    StaticIpConnectionInfoTypeDef,
    StorageLocationTypeDef,
    TagResourceRequestRequestTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDeviceMetadataRequestRequestTypeDef,
    UpdateDeviceMetadataResponseTypeDef,
)

def get_structure() -> ApplicationInstanceTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-panorama` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-panorama docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_panorama/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
